C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C*****************************
C**     LDM_GET_FBOX        **
C*****************************
C
C
CD-Doc:
C FIDBox           SUBROUTINE LDM_GET_FBOX (VALUE, IFLAG, ND)
CD-end
      SUBROUTINE LDM_GET_FBOX (VALUE, IFLAG, ND)
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: Get value of real parameter FIDBOX
C
C Author:  John W. Campbell, June 1993
C
C Arguments:
C
      REAL VALUE
      INTEGER IFLAG
      INTEGER ND

C  VALUE     (W)   Size of fiducials search box im mm
C  IFLAG     (W)   Flag = -1 undefined value
C                       =  0 default value
C                       =  1 value set explicitly
C                       =  2 value set globally
C ND         (W)   No. of decimal places for printing (- if E format)
C
C====== GLOBALS:
C
      INCLUDE 'ldm_data.finc'
      EXTERNAL LDM_BDAT
C
C====== LOCALS:
C

C
C-------------------------------------------------------------------------------
C
      VALUE = FBOX
      IFLAG = IS_FBOX
      ND = ND_FBOX
      IF (ND.EQ.-1000) ND = 2
      RETURN
      END
